Author: Andreas Tille <tille@debian.org>
Last-Update: Wed, 20 Apr 2016 10:31:32 +0200
Description: NO idea for what purpose setup.py is used - in any case
 it is seeking for a non-existing README file.

--- a/setup.py
+++ b/setup.py
@@ -17,11 +17,11 @@ setup(
       license = "BSD",
       keywords = "multialignment snps bionformatics",
       url = "http://github.com/marbl/parsnp",
-      long_description=read('README'),
+      long_description=read('README.md'),
       classifiers=[
                    "Development Status :: 1 - Release"
                    ],
       scripts=['src/parsnp.py'],
       #    ext_modules = ext_modules,
       cmdclass = {'build_ext': build_ext}
-      )
\ No newline at end of file
+      )
